aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorChristian Kandeler <christian.kandeler@digia.com>2013-04-12 14:18:59 +0200
committerJoerg Bornemann <joerg.bornemann@digia.com>2013-04-12 14:46:57 +0200
commita7f8f79dad4f25656f43159728c48d3aa6905b4d (patch)
treede378ac2a772b20c7970877cf9eb939851092cb4
parentafeaefae5c543fd48ab623718bc0dc902844bcbd (diff)
Skip non-applicable command line parser test on Windows.
There currently is no "--show-progress" option on that OS. Change-Id: I56150eadb69ac05d342d3a050c87e66bc79bd63f Reviewed-by: Joerg Bornemann <joerg.bornemann@digia.com>
-rw-r--r--tests/auto/cmdlineparser/tst_cmdlineparser.cpp13
1 files changed, 8 insertions, 5 deletions
diff --git a/tests/auto/cmdlineparser/tst_cmdlineparser.cpp b/tests/auto/cmdlineparser/tst_cmdlineparser.cpp
index 92d1072a4..cccbb636b 100644
--- a/tests/auto/cmdlineparser/tst_cmdlineparser.cpp
+++ b/tests/auto/cmdlineparser/tst_cmdlineparser.cpp
@@ -83,11 +83,14 @@ private slots:
QVERIFY(parser.parseCommandLine(QStringList() << "-t" << fileArgs, settings.data()));
QVERIFY(parser.logTime());
- // Note: We cannot just check for !parser.logTime() here, because if the test is not
- // run in a terminal, "--show-progress" is ignored, in which case "--log-time" takes effect.
- QVERIFY(parser.parseCommandLine(QStringList() << "-t" << "--show-progress" << fileArgs,
- settings.data()));
- QVERIFY(parser.showProgress() != parser.logTime());
+ if (!Internal::HostOsInfo::isWindowsHost()) { // Windows has no progress bar atm.
+ // Note: We cannot just check for !parser.logTime() here, because if the test is not
+ // run in a terminal, "--show-progress" is ignored, in which case "--log-time"
+ // takes effect.
+ QVERIFY(parser.parseCommandLine(QStringList() << "-t" << "--show-progress" << fileArgs,
+ settings.data()));
+ QVERIFY(parser.showProgress() != parser.logTime());
+ }
QVERIFY(parser.parseCommandLine(QStringList() << "-vvqqq" << fileArgs, settings.data()));
QCOMPARE(ConsoleLogger::instance().logSink()->logLevel(), LoggerWarning);